```{include} ../README.md

```

```{toctree}
:caption: General
:hidden: true
:maxdepth: 1

api.md
changelog.md
references.md
```

```{toctree}
:caption: Tutorials
:hidden: true
:maxdepth: 1

tutorials/biolord_pipeline
tutorials/biolord_classify
tutorials/biolord_omics
```
